﻿Imports System.Linq
Imports System.Net
Imports System.Windows
Imports System.Windows.Controls
Imports System.Windows.Navigation
Imports Microsoft.Phone.Controls
Imports Microsoft.Phone.Shell
Imports ContosoTransit.WP8App.Models
Imports Microsoft.Phone.Wallet
Imports System.Text.RegularExpressions
Imports System.Threading.Tasks
Imports ContosoTransit.WP8Library
Imports System.Windows.Media.Imaging

Namespace ContosoTransit.WP8App
	Partial Public Class StationPage
		Inherits PhoneApplicationPage
		Public Sub New()
			InitializeComponent()
            service = New MockTransitService
		End Sub

		Private walletCard As WalletTransactionItem
		Private service As MockTransitService
		Private station As StationModel


		Protected Overrides async Sub OnNavigatedTo(ByVal e As NavigationEventArgs)
			walletCard = TryCast(Wallet.FindItem("LoyaltyCard"), WalletTransactionItem)

			If walletCard Is Nothing Then
				checkinBtn.Visibility = Visibility.Collapsed
			Else
				checkinBtn.Visibility = Visibility.Visible
			End If

			Dim value As String = ""
			If NavigationContext.QueryString.TryGetValue("stationid", value) Then
				Dim id As Integer = Convert.ToInt32(value)

                station = service.GetStations.Where(Function(s) s.Id = id).SingleOrDefault

                Dim autoCheckin As String = String.Empty
				If NavigationContext.QueryString.TryGetValue("checkin", autoCheckin) Then
					If autoCheckin = "true" AndAlso walletCard IsNot Nothing Then
						await LoyaltyCardCheckIn()
					End If
				End If

				Me.DataContext = station
			End If

		End Sub

		Private async Sub checkinBtn_Click(ByVal sender As Object, ByVal e As RoutedEventArgs)
			If walletCard IsNot Nothing Then
				await LoyaltyCardCheckIn()
			End If
		End Sub

		Private async Function LoyaltyCardCheckIn() As Task
			await UpdateLoyaltyCard(station.Id)

			MessageBox.Show("Check in complete. Balance is " & walletCard.DisplayBalance)

			checkinBtn.Visibility = Visibility.Collapsed
		End Function


		Private async Function UpdateLoyaltyCard(ByVal stationId As Integer) As Task
			Dim balance As Integer = service.UpdatePointsOnCheckIn(walletCard.AccountNumber, stationId)

			walletCard.DisplayBalance = balance & " points"

			Dim deal As DealModel = service.GetDealForStationCheckIn(stationId)
			If deal IsNot Nothing Then
				Dim prompt As String = String.Format("A deal is available for {0} from {1}.  Add to wallet?", deal.Name, deal.Issuer)
				Dim result As MessageBoxResult = MessageBox.Show(prompt, "Coupon available", MessageBoxButton.OKCancel)
                If result = MessageBoxResult.OK Then
                    Await AddDealToWallet(deal)
                End If
			End If

            Await walletCard.SaveAsync
		End Function

		Private Shared async Function AddDealToWallet(ByVal model As DealModel) As Task
            Dim deal As New Deal
			deal.DisplayName = model.Name
			deal.IssuerName = model.Issuer
			deal.StartDate = Date.Now
			deal.ExpirationDate = Date.Now.AddDays(model.DaysValid)
			deal.IsUsed = False
			deal.Code = model.Code
			deal.MerchantName = model.Issuer
			deal.MerchantPhone.Business = model.MerchantPhone

            Dim LogoImg As New BitmapImage
            Dim LogoUri As New Uri(model.LogoImagePath, UriKind.Relative)
            LogoImg.SetSource(Application.GetResourceStream(LogoUri).Stream)
            deal.Logo99x99 = LogoImg
            deal.Logo159x159 = LogoImg
            deal.Logo336x336 = LogoImg

            Dim QrImg As New BitmapImage
            Dim QrUri As New Uri(model.QRImagePath, UriKind.Relative)
            QrImg.SetSource(Application.GetResourceStream(QrUri).Stream)
            deal.BarcodeImage = QrImg

            Await deal.SaveAsync
		End Function
	End Class
End Namespace